import 'dart:async';

import 'package:flutter/services.dart';

class StealthId {
  static const MethodChannel _channel = const MethodChannel('stealth_id');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// Executes the authentication on Unisys Platform based on facial biodata
  /// [args] Map needs a mandatory attribute named [userId] which is a User's unique identification
  static Future authenticateEnrolledUser(Map<String, dynamic> arg) async {
    final authData =
        await _channel.invokeMethod('authenticateEnrolledUser', arg);
    print("authenticateEnrolledUser result -> ${authData.toString()}");
    return authData;
  }

  static Future enrollUser(Map<String, dynamic> arg) async {
    final enrollmentResult = await _channel.invokeMethod('enrollUser', arg);
    print("enrollUser result -> ${enrollmentResult.toString()}");
    return enrollmentResult;
  }

  static Future captureOCR(Map<String, dynamic> arg) async {
    final ocrResult = await _channel.invokeMethod('captureOCR', arg);
    print("captureOCR result -> ${ocrResult.toString()}");
    return ocrResult is List ? ocrResult[0] : ocrResult;
  }

  static Future initiateClient() async {
    final credentialResult = await _channel.invokeMethod('initiateClient');
    print("initiateClient result -> ${credentialResult.toString()}");
    return credentialResult;
  }
}
